@@ -110,7 +110,7 @@ static bool autoDetectSystemProxy(QLineEdit* edit, const QString& envVarStr)
     Q_FOREACH (const QString & envVar, envVars) {
         const QByteArray envVarUtf8(envVar.toUtf8());
         if (!qgetenv(envVarUtf8.constData()).isEmpty()) {
-            edit->setText(envVarStr);
+            edit->setText(envVar);
             return true;
         }
     }
@@ -165,10 +165,6 @@ static void setProxyInformation(const QString& value,
                                 QSpinBox* spinBox ,
                                 KProxyDialog::DisplayUrlFlag flag)
 {
-    if (value.isEmpty()) {
-        return;
-    }
-
     kDebug() << value << "type=" << proxyType << manEdit << sysEdit << spinBox;
     const bool isSysProxy = (!value.contains(QL1C(' ')) &&
                              !value.contains(QL1C('.')) &&
@@ -260,6 +256,7 @@ KProxyDialog::KProxyDialog(QWidget* parent, const QVariantList& args)
     connect(mUi.autoDiscoverProxyRadioButton, SIGNAL(clicked()), SLOT(slotChanged()));
     connect(mUi.autoScriptProxyRadioButton, SIGNAL(clicked()), SLOT(slotChanged()));
     connect(mUi.manualProxyRadioButton, SIGNAL(clicked()), SLOT(slotChanged()));
+    connect(mUi.systemProxyRadioButton, SIGNAL(clicked()), SLOT(slotChanged()));
     connect(mUi.noProxyRadioButton, SIGNAL(clicked()), SLOT(slotChanged()));
     connect(mUi.useReverseProxyCheckBox, SIGNAL(clicked()), SLOT(slotChanged()));
     connect(mUi.useSameProxyCheckBox, SIGNAL(clicked()), SLOT(slotChanged()));
@@ -277,11 +274,11 @@ KProxyDialog::KProxyDialog(QWidget* parent, const QVariantList& args)
     connect(mUi.manualProxyFtpSpinBox, SIGNAL(valueChanged(int)), SLOT(slotChanged()));
     connect(mUi.manualProxySocksSpinBox, SIGNAL(valueChanged(int)), SLOT(slotChanged()));
 
-    connect(mUi.systemProxyHttpEdit, SIGNAL(textChanged(QString)), SLOT(slotChanged()));
-    connect(mUi.systemProxyHttpsEdit, SIGNAL(textChanged(QString)), SLOT(slotChanged()));
-    connect(mUi.systemProxyFtpEdit, SIGNAL(textChanged(QString)), SLOT(slotChanged()));
-    connect(mUi.systemProxySocksEdit, SIGNAL(textChanged(QString)), SLOT(slotChanged()));
-    connect(mUi.systemNoProxyEdit, SIGNAL(textChanged(QString)), SLOT(slotChanged()));    
+    connect(mUi.systemProxyHttpEdit, SIGNAL(textEdited(QString)), SLOT(slotChanged()));
+    connect(mUi.systemProxyHttpsEdit, SIGNAL(textEdited(QString)), SLOT(slotChanged()));
+    connect(mUi.systemProxyFtpEdit, SIGNAL(textEdited(QString)), SLOT(slotChanged()));
+    connect(mUi.systemProxySocksEdit, SIGNAL(textEdited(QString)), SLOT(slotChanged()));
+    connect(mUi.systemNoProxyEdit, SIGNAL(textEdited(QString)), SLOT(slotChanged()));
 }
 
 KProxyDialog::~KProxyDialog()
@@ -299,6 +296,9 @@ void KProxyDialog::load()
 
     const int proxyType = KProtocolManager::proxyType();
 
+    // Make sure showEnvValueCheckBox is unchecked before setting proxy env var names
+    mUi.showEnvValueCheckBox->setChecked(false);
+
     setProxyInformation(mProxyMap.value(QL1S("HttpProxy")), proxyType, mUi.manualProxyHttpEdit, mUi.systemProxyHttpEdit, mUi.manualProxyHttpSpinBox, HideHttpUrlScheme);
     setProxyInformation(mProxyMap.value(QL1S("HttpsProxy")), proxyType, mUi.manualProxyHttpsEdit, mUi.systemProxyHttpsEdit, mUi.manualProxyHttpsSpinBox, HideHttpsUrlScheme);
     setProxyInformation(mProxyMap.value(QL1S("FtpProxy")), proxyType, mUi.manualProxyFtpEdit, mUi.systemProxyFtpEdit, mUi.manualProxyFtpSpinBox, HideFtpUrlScheme);
@@ -371,11 +371,20 @@ void KProxyDialog::save()
         displayUrlFlags = flags;
     } else if (mUi.systemProxyRadioButton->isChecked()) {
         proxyType = KProtocolManager::EnvVarProxy;
-        mProxyMap[QL1S("HttpProxy")] = mUi.systemProxyHttpEdit->text();
-        mProxyMap[QL1S("HttpsProxy")] = mUi.systemProxyHttpsEdit->text();
-        mProxyMap[QL1S("FtpProxy")] = mUi.systemProxyFtpEdit->text();
-        mProxyMap[QL1S("SocksProxy")] = mUi.systemProxySocksEdit->text();
-        mProxyMap[QL1S("NoProxy")] = mUi.systemNoProxyEdit->text();
+        if (!mUi.showEnvValueCheckBox->isChecked()) {
+            mProxyMap[QL1S("HttpProxy")] = mUi.systemProxyHttpEdit->text();
+            mProxyMap[QL1S("HttpsProxy")] = mUi.systemProxyHttpsEdit->text();
+            mProxyMap[QL1S("FtpProxy")] = mUi.systemProxyFtpEdit->text();
+            mProxyMap[QL1S("SocksProxy")] = mUi.systemProxySocksEdit->text();
+            mProxyMap[QL1S("NoProxy")] = mUi.systemNoProxyEdit->text();
+        }
+        else {
+            mProxyMap[QL1S("HttpProxy")] = mProxyMap.take(QL1S("EnvVarProxyHttp"));
+            mProxyMap[QL1S("HttpsProxy")] = mProxyMap.take(QL1S("EnvVarProxyHttps"));
+            mProxyMap[QL1S("FtpProxy")] = mProxyMap.take(QL1S("EnvVarProxyFtp"));
+            mProxyMap[QL1S("SocksProxy")] = mProxyMap.take(QL1S("EnvVarProxySocks"));
+            mProxyMap[QL1S("NoProxy")] = mProxyMap.take(QL1S("EnvVarNoProxy"));
+        }
     } else if (mUi.autoScriptProxyRadioButton->isChecked()) {
         proxyType = KProtocolManager::PACProxy;
         mProxyMap[QL1S("ProxyScript")] = mUi.proxyScriptUrlRequester->text();
